Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1076)

Unified Diff: pkg/analysis_server/lib/analysis/index_core.dart

Issue 1359113002: Use IndexContributor(s) in LocalIndex. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/analysis_server/lib/analysis/index/index_dart.dart ('k') | pkg/analysis_server/lib/plugin/index.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analysis_server/lib/analysis/index_core.dart
diff --git a/pkg/analysis_server/lib/analysis/index/index_core.dart b/pkg/analysis_server/lib/analysis/index_core.dart
similarity index 97%
rename from pkg/analysis_server/lib/analysis/index/index_core.dart
rename to pkg/analysis_server/lib/analysis/index_core.dart
index 81d232d8b2da36efd16a00916173d77a1437daeb..aac9d8a303bc800df776a0c824d761cdeccde080 100644
--- a/pkg/analysis_server/lib/analysis/index/index_core.dart
+++ b/pkg/analysis_server/lib/analysis/index_core.dart
@@ -115,10 +115,10 @@ abstract class IndexableObjectKind {
*/
abstract class IndexContributor {
/**
* Contribute relationships to the given index [store] as a result of
* analyzing the given [source] in the given [context].
*/
- void contributeTo(IndexStore store, AnalysisContext context, Source source);
+ void contributeTo(IndexStore store, AnalysisContext context, Object object);
}
// A sketch of what the driver routine might look like:
« no previous file with comments | « pkg/analysis_server/lib/analysis/index/index_dart.dart ('k') | pkg/analysis_server/lib/plugin/index.dart » ('j') | no next file with comments »
@@ -115,10 +115,10 @@ abstract class IndexableObjectKind {
abstract class IndexContributor {
/**
- * Contribute relationships to the given index [store] as a result of
- * analyzing the given [source] in the given [context].
+ * Contribute relationships existing in the given [object] to the given
+ * index [store] in the given [context].
*/

Powered by Google App Engine
This is Rietveld 408576698